"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const comparator_1 = require("./filtering/comparator");
const matcher_1 = require("./filtering/matcher");
const recording_1 = require("./recording");
/**
 * Store the current execution context for YesNo by tracking requests & mocks.
 */
class Context {
    constructor() {
        this.mode = recording_1.RecordMode.Spy;
        /**
         * Completed serialized request-response objects. Used for:
         * A. Assertions
         * B. Saved to disk if in record mode
         */
        this.interceptedRequestsCompleted = [];
        /**
         * Serialized records loaded from disk.
         */
        this.loadedMocks = [];
        /**
         * Proxied requests which have not yet responded. When completed
         * the value is set to "null" but the index is preserved.
         */
        this.inFlightRequests = [];
        this.responsesForMatchingRequests = [];
        this.comparatorFn = comparator_1.byUrl;
    }
    clear() {
        this.interceptedRequestsCompleted = [];
        this.inFlightRequests = [];
        this.loadedMocks = [];
        this.responsesForMatchingRequests = [];
        this.comparatorFn = comparator_1.byUrl;
    }
    getMatchingMocks(matcher) {
        return this.loadedMocks.filter(matcher_1.match(matcher));
    }
    getMatchingIntercepted(matcher) {
        return this.interceptedRequestsCompleted.filter(matcher_1.match(matcher));
    }
    hasResponsesDefinedForMatchers() {
        return !!this.responsesForMatchingRequests.length;
    }
    addResponseForMatchingRequests(matchingResponse) {
        this.responsesForMatchingRequests.push(matchingResponse);
    }
    getResponseDefinedMatching(request) {
        let firstMatchingResponse;
        for (const { matcher, response } of this.responsesForMatchingRequests) {
            const doesMatch = matcher_1.match(matcher)({ request });
            if (doesMatch) {
                firstMatchingResponse = Object.assign({ body: {}, headers: {} }, (typeof response === 'function' ? response(request) : response));
                break;
            }
        }
        return firstMatchingResponse;
    }
}
exports.default = Context;
//# sourceMappingURL=context.js.map