"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const lodash_1 = __importDefault(require("lodash"));
const http_serializer_1 = require("../http-serializer");
exports.EMPTY_RESPONSE = { body: {}, headers: {}, statusCode: 0 };
/**
 * Curried function to determine whether a query matches an intercepted request.
 *
 * Query objects must be a deep partial match against the intercepted request.
 *
 * RegEx values are tested for match.
 */
function match(fnOrPartialMatch) {
    const equalityOrRegExpDeep = (reqResValue, queryValue) => {
        if (queryValue instanceof RegExp) {
            return queryValue.test(reqResValue);
        }
        else if (lodash_1.default.isPlainObject(queryValue) || lodash_1.default.isArray(queryValue)) {
            // Add a depth limit?
            return lodash_1.default.isMatchWith(reqResValue, queryValue, equalityOrRegExpDeep);
        }
        else {
            return queryValue === reqResValue;
        }
    };
    const matcher = lodash_1.default.isFunction(fnOrPartialMatch)
        ? fnOrPartialMatch
        : (serialized) => {
            const query = fnOrPartialMatch;
            let isMatch = true;
            if (query.url) {
                const matchUrlNoPort = equalityOrRegExpDeep(http_serializer_1.formatUrl(serialized.request), query.url);
                const matchUrlPort = equalityOrRegExpDeep(http_serializer_1.formatUrl(serialized.request, true), query.url);
                isMatch = isMatch && (matchUrlNoPort || matchUrlPort);
            }
            if (query.request) {
                isMatch =
                    isMatch && lodash_1.default.isMatchWith(serialized.request, query.request, equalityOrRegExpDeep);
            }
            if (query.response) {
                isMatch =
                    isMatch && lodash_1.default.isMatchWith(serialized.response, query.response, equalityOrRegExpDeep);
            }
            return isMatch;
        };
    return (serialized) => matcher({
        request: serialized.request,
        // Response will be empty if matching against requests
        response: serialized.response || exports.EMPTY_RESPONSE,
    });
}
exports.match = match;
//# sourceMappingURL=matcher.js.map