import { IFileOptions } from './file';
import { ISerializedHttp } from './http-serializer';
export declare enum RecordMode {
    /**
     * Intercept requests and respond with local mocks
     */
    Mock = "mock",
    /**
     * Spy on request/response
     */
    Spy = "spy",
    /**
     * Save requests
     */
    Record = "record"
}
export interface IRecordingOptions extends IFileOptions {
    /**
     * Get all recorded HTTP requests we need to save to disc
     */
    getRecordsToSave: () => ISerializedHttp[];
    /**
     * Current record mode. Determines whether or not we'll save to disc on completion.
     */
    mode: RecordMode;
}
/**
 * Represents a single YesNo recording
 */
export default class Recording {
    private options;
    constructor(options: IRecordingOptions);
    /**
     * Complete recording by saving all HTTP requests to disc if in record mode.
     * No-op otherwise.
     */
    complete(): Promise<string | undefined>;
}
