"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const file_1 = require("./file");
const debug = require('debug')('yesno:recording');
var RecordMode;
(function (RecordMode) {
    /**
     * Intercept requests and respond with local mocks
     */
    RecordMode["Mock"] = "mock";
    /**
     * Spy on request/response
     */
    RecordMode["Spy"] = "spy";
    /**
     * Save requests
     */
    RecordMode["Record"] = "record";
})(RecordMode = exports.RecordMode || (exports.RecordMode = {}));
/**
 * Represents a single YesNo recording
 */
class Recording {
    constructor(options) {
        this.options = options;
    }
    /**
     * Complete recording by saving all HTTP requests to disc if in record mode.
     * No-op otherwise.
     */
    complete() {
        if (this.options.mode === RecordMode.Record) {
            debug('Record mode, saving');
            return file_1.save(Object.assign({}, this.options, { records: this.options.getRecordsToSave() }));
        }
        debug('"%s" mode, no-op', this.options.mode);
        return Promise.resolve(undefined);
    }
}
exports.default = Recording;
//# sourceMappingURL=recording.js.map